Learn R Programming

qdapRegex (version 0.1.1)

rm_abbreviation: Remove/Replace/Extract Abbreviations

Description

Remove/replace/extract abbreviations from a string containing lower case or capital letters followed by a period and then an optional space (this must be repeated 2 or more times).

Usage

rm_abbreviation(text.var, trim = !extract, clean = TRUE,
  pattern = "@rm_abbreviation", replacement = "", extract = FALSE,
  dictionary = getOption("regex.library"), ...)

Arguments

text.var
The text variable.
trim
logical. If TRUE removes leading and trailing white spaces.
clean
trim logical. If TRUE extra white spaces and escaped character will be removed.
pattern
A character string containing a regular expression (or character string for fixed = TRUE) to be matched in the given character vector. Default, @rm_abbreviation uses the rm_abbreviation regex from the regular exp
replacement
Replacement for matched pattern.
extract
logical. If TRUE the abbreviations are extracted into a list of vectors.
dictionary
A dictionary of canned regular expressions to search within if pattern begins with "@rm_".
...
Other arguments passed to gsub.

Value

  • Returns a character string with abbreviations removed.

See Also

gsub, stri_extract_all_regex

Examples

Run this code
x <- c("I want $2.33 at 2:30 p.m. to go to A.n.p.",
    "She will send it A.S.A.P. (e.g. as soon as you can) said I.",
    "Hello world.", "In the U. S. A.")
rm_abbreviation(x)
rm_abbreviation(x, extract=TRUE)

Run the code above in your browser using DataLab