Learn R Programming

qdapRegex (version 0.1.1)

rm_city_state: Remove/Replace/Extract City & State

Description

Remove/replace/extract city (single lower case word or multiple consecutive capitalized words before a comma and state) & state (2 consecutive capital letters) from a string.

Usage

rm_city_state(text.var, trim = !extract, clean = TRUE,
  pattern = "@rm_city_state", replacement = "", extract = FALSE,
  dictionary = getOption("regex.library"), ...)

Arguments

text.var
The text variable.
trim
logical. If TRUE removes leading and trailing white spaces.
clean
trim logical. If TRUE extra white spaces and escaped character will be removed.
pattern
A character string containing a regular expression (or character string for fixed = TRUE) to be matched in the given character vector. Default, @rm_city_state uses the rm_city_state regex from the regular express
replacement
Replacement for matched pattern.
extract
logical. If TRUE the city & state are extracted into a list of vectors.
dictionary
A dictionary of canned regular expressions to search within if pattern begins with "@rm_".
...
Other arguments passed to gsub.

Value

  • Returns a character string with city & state removed.

See Also

gsub, stri_extract_all_regex

Examples

Run this code
x <- paste0("I went to Washington Heights, NY for food! ",
   "It's in West ven,PA, near Bolly Bolly Bolly, CA!",
   "I like Movies, PG13")
rm_city_state(x)
rm_city_state(x, extract=TRUE)

Run the code above in your browser using DataLab