Learn R Programming

qdapRegex (version 0.3.2)

rm_non_ascii: Remove/Replace/Extract Non-ASCII

Description

Remove/replace/extract non-ASCII substring from a string. This is the template used by other qdapRegex rm_XXX functions.

Usage

rm_non_ascii(text.var, trim = !extract, clean = TRUE,
  pattern = "@rm_non_ascii", replacement = "", extract = FALSE,
  dictionary = getOption("regex.library"), ascii.out = TRUE, ...)

Arguments

text.var
The text variable.
trim
logical. If TRUE removes leading and trailing white spaces.
clean
trim logical. If TRUE extra white spaces and escaped character will be removed.
pattern
A character string containing a regular expression (or character string for fixed = TRUE) to be matched in the given character vector. Default, @rm_non_ascii uses the rm_non_ascii regex from the regular expressio
replacement
Replacement for matched pattern.
extract
logical. If TRUE the all non-ASCII strings are extracted into a list of vectors.
dictionary
A dictionary of canned regular expressions to search within if pattern begins with "@rm_".
ascii.out
logical. If TRUE output is given in non-ASCII format, otherwise "byte" is used.
...
ignored.

Value

  • Returns a character string with "all caps" removed.

Warning

iconv is used within rm_non_ascii. iconv's behavior across operating systems may not be consistent.

References

The email regular expression was taken from: http://stackoverflow.com/a/25469131/1000343

See Also

gsub, stri_extract_all_regex Other rm_.functions: rm_abbreviation; rm_angle, rm_bracket, rm_bracket_multiple, rm_curly, rm_round, rm_square; rm_between, rm_between_multiple; rm_caps_phrase; rm_caps; rm_citation_tex; rm_citation; rm_city_state_zip; rm_city_state; rm_date; rm_default; rm_dollar; rm_email; rm_emoticon; rm_endmark; rm_hash; rm_nchar_words; rm_number; rm_percent; rm_phone; rm_postal_code; rm_repeated_characters; rm_repeated_phrases; rm_repeated_words; rm_tag; rm_time; rm_title_name; rm_twitter_url, rm_url; rm_white, rm_white_bracket, rm_white_colon, rm_white_comma, rm_white_endmark, rm_white_lead, rm_white_lead_trail, rm_white_multiple, rm_white_punctuation, rm_white_trail; rm_zip

Examples

Run this code
x <- c("Hello World", "Ekstr\xf8m", "J\xf6reskog", "bi\xdfchen Z\xfcrcher")
Encoding(x) <- "latin1"
x

rm_non_ascii(x)
rm_non_ascii(x, replacement="<<FLAG>>")
rm_non_ascii(x, extract=TRUE)
rm_non_ascii(x, extract=TRUE, ascii.out=FALSE)

Run the code above in your browser using DataLab