Learn R Programming

qdapRegex (version 0.1.1)

rm_title_name: Remove/Replace/Extract Title + Person Name

Description

Remove/replace/extract title (honorific) + person name(s) from a string.

Usage

rm_title_name(text.var, trim = !extract, clean = TRUE,
  pattern = "@rm_title_name", replacement = "", extract = FALSE,
  dictionary = getOption("regex.library"), ...)

Arguments

text.var
The text variable.
trim
logical. If TRUE removes leading and trailing white spaces.
clean
trim logical. If TRUE extra white spaces and escaped character will be removed.
pattern
A character string containing a regular expression (or character string for fixed = TRUE) to be matched in the given character vector. Default, @rm_title_name uses the rm_title_name regex from the regular express
replacement
Replacement for matched pattern.
extract
logical. If TRUE the person tags are extracted into a list of vectors.
dictionary
A dictionary of canned regular expressions to search within if pattern begins with "@rm_".
...
Other arguments passed to gsub.

Value

  • Returns a character string with person tags removed.

See Also

gsub, stri_extract_all_regex

Examples

Run this code
x <- c("Dr. Brend is mizz hart's in mrs. Holtz's.",
    "Where is mr. Bob Jr. and Ms. John Kennedy?")

rm_title_name(x)
rm_title_name(x, extract=TRUE)

Run the code above in your browser using DataLab